@@ -53,7 +53,7 @@ class NoDevicesDialog(QDialog, Ui_NoDevicesDialog_base):
         if utils.which('hp-setup'):
             cmd = 'hp-setup -u'
         else:
-            cmd = '/usr/local/bin/python2.6 ./setup.py -u'
+            cmd = '/usr/local/bin/python2.7 ./setup.py -u'
 
         log.debug(cmd)
         utils.run(cmd, log_output=True, password_func=None, timeout=1)
@@ -71,7 +71,7 @@ class NoDevicesDialog(QDialog, Ui_NoDevicesDialog_base):
 
     def CUPSButton_clicked(self):
         self.close()
-        utils.openURL("http://localhost:631/admin/")
+        utils.openURL("http://localhost:631/admin")
 
 
     def CloseButton_clicked(self):
